<?php

namespace Modules\Pp\Http\Controllers;

use Illuminate\Contracts\Support\Renderable;
use Illuminate\Http\Request;
use Illuminate\Routing\Controller;
use Modules\Pp\Entities\PurchaseOrder;
use Modules\Pp\Entities\CustomerPlan;
use Modules\Pp\Entities\CustomerPlanData;
use Modules\Pp\Entities\Product;
use Illuminate\Support\Facades\DB;
use Modules\Pp\Entities\CustomerOrder;

class SupplyPlanController extends Controller
{
    // functions by nipuna start
    public function addorderPurchaceOrder(){
        try {
            $data=new CustomerOrder();
            $allOrders=$data->all();

            $responseBody = $this->responseBody(true, "CustomerPlan", "all", $allOrders);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "CustomerPlan", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }
    // functions by nipuna end

   /**
     * PurchaseOrder
     * This function is used to search purchase order from order id.
     * @return Json This returns as response.
     */

     //modified by nipuna
    public function productToPurchaseOrder($id)
    {
        try {
            $purchaseOrder = DB::select("SELECT * from pp_customer_orders_data WHERE order_id = " . $id );
            $responseBody = $this->responseBody(true, "productToPurchaseOrder", "found", $purchaseOrder);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "productToPurchaseOrder", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }
    //function by nipuna start
    public function productQuantity($id){
        try {
            $purchaseOrder = DB::select("SELECT quantity_pieces from pp_customer_orders_data WHERE order_data_id = " . $id );
            $responseBody = $this->responseBody(true, "productQuantity", "found", $purchaseOrder);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "productQuantity", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }
    //function by nipuna end


    /**
     * settings
     * This function is used to search settings records from the database.
     * @return Json This returns as response.
     */
    public function settings()
    {

        try {

            $purchaseOrder = PurchaseOrder::where('status', '=', 0 )->get();
            $result = [
                "PurchaseOrder" => $purchaseOrder,
            ];
            $responseBody = $this->responseBody(true, "Settings", "all", $result);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "error", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }


    /**
     * responseBody
     * This is used to create response.
     * @param success This is the paramter require boolean
     * @param name This is the paramter require ui table name
     * @param message This is the paramter require message content
     * @param result This is the paramter require result as some of data to return client
     * @return Json This returns as response.
     */
    private function responseBody($success, $name, $message, $result)
    {
        $body = [
            "success" => $success,
            "message" => $message,
            "name" => $name,
            "result" => $result
        ];
        return $body;
    }


    /**
     * save
     * This function is used to save new Customer Order to database.
     * @param request This is the paramter to save function
     * @return Json This returns as response.
     */
    public function save(Request $request)
    {

        try {

            $customerPlan = new CustomerPlan();
            $customerPlan->order_id = $request->get('selcPurchaseOrder');
            $customerPlan->order_data_id=$request->get("hidProduct");
            $customerPlan->manufacturing_order_number=$request->get('inpManuOrderNum');
            $customerPlan->trans_date = $request->get('dteDate');
            $customerPlan->plan_year = $request->get('selcPlanYear');
            $customerPlan->plan_month = $request->get('selcPlanMonth');
            $customerPlan->description = $request->get('txtDescription');
            // $customerPlan->orderdata_id = $request->get('hidProduct');
            // $customerPlan->manufacture_order_num = $request->get('inpManuOrderNum');


            $save = $customerPlan->save();

            if ($save) {
                $responseBody = $this->responseBody(true, "CustomerPlan", "saved", $customerPlan);
            }
        }

        catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "error", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }

    /**
     * saveData
     * This function is used to save new customer order data to database.
     * @param request This is the paramter to save function
     * @return Json This returns as response.
     */
    public function saveData(Request $request)
    {

        try {

            $customerPlanData = new CustomerPlanData();
            $customerPlanData->customer_order_plan_id = $request->get('txtOrderId');
            $customerPlanData->start_date = $request->get('dteStartDate');
            $customerPlanData->end_date = $request->get('dteEndDate');
            $customerPlanData->product_id = $request->get('txtProductID');
            $customerPlanData->product_name = $request->get('txtProductName');
            $customerPlanData->quantity = $request->get('txtQuantity');
            $customerPlanData->status = true;
            $save = $customerPlanData->save();

            if ($save) {
                $responseBody = $this->responseBody(true, "CustomerPlanData", "saved", $customerPlanData);
            }
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "error", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }



    /**
     * allOrderPlan
     * This function is used to search all customer order records from the database.
     * @return Json This returns as response.
     */
    public function allOrderPlan()
    {

        try {
            $customerPlan =  CustomerPlan::orderBy('order_id')->get();
            $responseBody = $this->responseBody(true, "CustomerPlan", "all", $customerPlan);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "error", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }


    /**
     * allOrderPlanData
     * This function is used to search all customer order data records from the database.
     * @return Json This returns as response.
     */
    public function allOrderPlanData($id)
    {

        try {
            $customerPlanData = CustomerPlanData::find($id);
            $customerPlanData =  CustomerPlanData::where('customer_order_plan_id', $id)->get();
            $responseBody = $this->responseBody(true, "CustomerPlanData", "all", $customerPlanData);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "error", "error", $exception);
        }

        return response()->json(["data" => $responseBody]);
    }

    /**
     * deleteOrder
     * This function is used to delete customer order from customer order id.
     * @return Json This returns as response.
     */
    public function deleteOrder($id)
    {
        try {
            $customerPlan = CustomerPlan::find($id);
            $delete = $customerPlan->delete();
            if ($delete) {
                $responseBody = $this->responseBody(true, "CustomerPlan", "deleted", null);
            }
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "error", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }


    /**
     * deleteOrderData
     * This function is used to delete customer order plan from customer order plan id.
     * @return Json This returns as response.
     */
    public function deleteOrderData($id)
    {
        try {
            $customerPlanData = CustomerPlanData::find($id);
            $deleteData = $customerPlanData->delete();
            if ($deleteData) {
                $responseBody = $this->responseBody(true, "CustomerPlanData", "deleted", $customerPlanData);
            }
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "error", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }


    /**
     * customerPlan
     * This function is used to search customer order plan from customer order plan id.
     * @return Json This returns as response.
     */
    public function customerPlan($id)
    {

        try {
            $customerPlan = CustomerPlan::find($id);
            $order_id = $customerPlan->order_id;
            $purchase_order = DB::table('pp_orders')->where('order_id', '=', $order_id)->first();

            $settings = [
                "purchase_order" => $purchase_order->purchase_order,
            ];

            $responseBody = $this->responseBody(true, "CustomerPlan", "all", ["customerPlan" => $customerPlan, "settings" => $settings]);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "error", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }

    /**
     * customerPlanData
     * This function is used to search customer order plan from customer order plan id.
     * @return Json This returns as response.
     */
    public function customerPlanData($id)
    {

        try {
            $customerPlanData = CustomerPlanData::find($id);



            $responseBody = $this->responseBody(true, "CustomerPlanData", "all", ["customerPlanData" => $customerPlanData]);
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "error", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }



       /**
     * updatePlan
     * This function is used to update customer order plan.
     * @param request This is the paramter to update function
     * @return Json This returns as response.
     */
    public function updatePlan(Request $request)
    {

        try {

           $id = $request->get('hidOrderID');
            $customerPlan = CustomerPlan::find($id);
            $customerPlan->order_id = $request->get('selcPurchaseOrder');
            $customerPlan->trans_date = $request->get('dteDate');
            $customerPlan->plan_year = $request->get('selcPlanYear');
            $customerPlan->plan_month = $request->get('selcPlanMonth');
            $customerPlan->description = $request->get('txtDescription');
            $save = $customerPlan->save();

            if ($save) {
                $responseBody = $this->responseBody(true, "CustomerPlan", "updated",  $customerPlan);
            }
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "error", $customerPlan, $exception);
        }
        return response()->json(["data" => $responseBody]);
    }


    /**
     * updatePlanData
     * This function is used to update customer order plan data.
     * @param request This is the paramter to update function
     * @return Json This returns as response.
     */
    public function updatePlanData(Request $request)
    {

        try {

            $id = $request->get('hidOrderPlanID');
            $customerPlanData = CustomerPlanData::find($id);
            $customerPlanData->customer_order_plan_id = $request->get('txtOrderId');
            $customerPlanData->start_date = $request->get('dteStartDate');
            $customerPlanData->end_date = $request->get('dteEndDate');
            $customerPlanData->product_id = $request->get('txtProductID');
            $customerPlanData->product_name = $request->get('txtProductName');
            $customerPlanData->quantity = $request->get('txtQuantity');
            $save = $customerPlanData->save();

            if ($save) {
                $responseBody = $this->responseBody(true, "CustomerPlanData", "updated", "");
            }
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "error", $customerPlanData, $exception);
        }
        return response()->json(["data" => $responseBody]);
    }



    /**
     * searchName
     * This function is used to search employee name from product id.
     * @return Json This returns as response.
     */
    public function searchPName()
    {
        $data = Product::where('product_type_id', '=', 4 )->get();
        $searchAray = [];
        for ($j = 0; $j < count($data); $j++) {
            array_push($searchAray, [
                "img" => "",
                "id" => $data[$j]['product_id'],
                "value" => $data[$j]['product_name'],
            ]);
        }
        return response()->json($searchAray);
    }


    public function getPName($product_id)
    {
        $data = Product::find($product_id);
        return response()->json($data);
    }


    /**
     * disableCustomerPlanData
     * This function is used to disable customer order plan data records.
     * @param request This is the paramter to disableCustomerPlanData function
     * @param id This is the paramter for identify update record.
     */
    public function disableCustomerPlanData(Request $request, $id)
    {
        try {

            $value = $request->get('status');

            $object = CustomerPlanData::find($id);
            $object->status = $value;
            $update = $object->save();
            if ($update) {
                $responseBody = $this->responseBody(true, "CustomerPlanData", "updated", null);
            }
        } catch (\Exception $exception) {
            $responseBody = $this->responseBody(false, "CustomerPlanData", "error", null);
        }
        return response()->json(["data" => $responseBody]);
    }



}
