<?php

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

use Illuminate\Support\Facades\Route;
use Modules\Pp\Http\Controllers\OrderController;
use Modules\Pp\Http\Controllers\CustomerOrderController;
use Modules\Pp\Http\Controllers\SettingsController;
use Modules\Pp\Http\Controllers\AttachmentController;
use Modules\Pp\Http\Controllers\SupplyPlanController;
use Modules\Pp\Http\Controllers\BillOfMaterialController;
use Modules\Pp\Http\Controllers\DailyCollectionPlanController;
use Modules\Pp\Http\Controllers\PpMachineryController;
use Modules\Pp\Http\Controllers\ProductionPlanController;

Route::prefix('pp')->group(function () {
    //Route::get('/', 'PpController@index');

    Route::get('/dashboard', function () {
        return view('pp::dashboard');
    })->middleware('is.logged');

    Route::get('/settings', function () {
        return view('pp::settings');
    })->middleware('is.logged');

    Route::get('/customerOrder', function () {
        return view('pp::customerOrder');
    })->middleware('is.logged');

    Route::get('/orderList', function () {
        return view('pp::orderList');
    })->middleware('is.logged');

    Route::get('/attachment', function () {
        return view('pp::attachment');
    })->middleware('is.logged');

    Route::get('/customerPlan', function () {
        return view('pp::customerPlan');
    })->middleware('is.logged');


    Route::get('/billOfMaterial', function () {
        return view('pp::billOfMaterial');
    })->middleware('is.logged');

    Route::get('/planDailyCollection', function () {
        return view('pp::dailyCollectionPlan');
    })->middleware('is.logged');



   /** Settings */
    Route::post('/settings/shippingterm', [SettingsController::class, 'saveShippingTerm']);
    Route::post('/settings/productmix', [SettingsController::class, 'saveProductMix']);
    Route::post('/settings/washedlevel', [SettingsController::class, 'saveWashedLevel']);
    Route::post('/settings/plantholesize', [SettingsController::class, 'savePlantHoleSize']);

    Route::get('/settings/shippingterms', [SettingsController::class, 'allShippingTerm']);
    Route::get('/settings/productmixes', [SettingsController::class, 'allProductMix']);
    Route::get('/settings/washedlevels', [SettingsController::class, 'allWashedLevel']);
    Route::get('/settings/plantholesizes', [SettingsController::class, 'allPlantHoleSize']);

    Route::put('/settings/shippingterm/{id}', [SettingsController::class, 'updateShippingTerm']);
    Route::put('/settings/productmix/{id}', [SettingsController::class, 'updateProductMix']);
    Route::put('/settings/washedlevel/{id}', [SettingsController::class, 'updateWashedLevel']);
    Route::put('/settings/plantholesize/{id}', [SettingsController::class, 'updatePlantHoleSize']);

    Route::delete('/settings/shippingterm/{id}', [SettingsController::class, 'disableShippingTerm']);
    Route::delete('/settings/productmix/{id}', [SettingsController::class, 'disableProductMix']);
    Route::delete('/settings/washedlevel/{id}', [SettingsController::class, 'disableWashedLevel']);
    Route::delete('/settings/plantholesize/{id}', [SettingsController::class, 'desablePlantHoleSize']);

    Route::delete('/settings/shippingterm/delete/{id}', [SettingsController::class, 'deleteShippingTerm']);
    Route::delete('/settings/productmix/delete/{id}', [SettingsController::class, 'deleteProductMix']);
    Route::delete('/settings/washedlevel/delete/{id}', [SettingsController::class, 'deleteWashedLevel']);
    Route::delete('/settings/plantholesize/delete/{id}', [SettingsController::class, 'deletePlantHoleSize']);
    /** End Settings */


    /** Order */
    // Route::post('/order',[OrderController::class,'save']);
    // Route::post('/order/update',[OrderController::class,'update']);
    // Route::get('/order/allOrder',[OrderController::class,'allOrder']);
    // Route::get('/order/order/{id}',[OrderController::class,'order']);
    // Route::get('/order/settings',[OrderController::class,'settings']);
    // Route::delete('/order/{id}',[OrderController::class,'delete']);
    // Route::delete('/order/order/{id}',[OrderController::class,'disable']);
    /** End Order */

    /** Customer Order */
    Route::post('/order', [CustomerOrderController::class, 'save']);
    Route::get('/order/settings', [CustomerOrderController::class, 'settings']);
    Route::get('/order/allOrder', [CustomerOrderController::class, 'allOrder']);
    Route::get('/order/order/{id}', [CustomerOrderController::class, 'order']);
    Route::post('/order/update', [CustomerOrderController::class, 'update']);
    Route::delete('/order/{id}', [CustomerOrderController::class, 'delete']);
    Route::delete('/order/order/{id}', [CustomerOrderController::class, 'disable']);
    Route::post('/orderData', [CustomerOrderController::class, 'saveData']); //this is modifide below by nipuna
    // Route::post('/orderData',[CustomerOrderController::class,'validateFormData']);
    Route::get('customers/all',[CustomerOrderController::class,'allCustomers']);
    Route::get('SelectedCustomers/data/{id}',[CustomerOrderController::class,'SelectedCustomersData']);


    Route::post('/order/updateID', [CustomerOrderController::class, 'updateID']);
    //Route::delete('/order/order/{id}',[CustomerOrderController::class,'disable']);
    Route::get('/order/allOrderData', [CustomerOrderController::class, 'allOrderData']);
    Route::get('/orderData/allOrderData/{id}', [CustomerOrderController::class, 'allOrderDataView']);
    //Route::delete('/order/disable/{id}',[CustomerOrderController::class,'disableOrder']);
    Route::get('/orderData/orderData/{id}', [CustomerOrderController::class, 'orderData']);
    Route::post('/orderData/update', [CustomerOrderController::class, 'updateOrderData']);
    Route::delete('/orderData/{id}', [CustomerOrderController::class, 'deleteData']);
    /** End Customer Order */

    /** Attachment */
    Route::get('/attachment/allOrder', [AttachmentController::class, 'allOrder']);
    Route::get('/attachment/allOrder/{id}', [AttachmentController::class, 'getOrderFromId']);
    Route::get('/attachment/delete/{id}', [AttachmentController::class, 'delete']);
    Route::get('/attachment/allFiles/{id}', [AttachmentController::class, 'allFiles']);
    Route::get('/attachment/allOrderFiles', [AttachmentController::class, 'allOrderFiles']);
    Route::post('/attachment/upload', [AttachmentController::class, 'upload'])->name('upload');
    Route::post('/attachment/updateAttachmentID', [AttachmentController::class, 'updateAttachmentID']);
    /** End Attachment */

    /**Customer Plan */
    Route::get('/customerPlan/productToPurchaseOrder/{id}', [SupplyPlanController::class, 'productToPurchaseOrder']); //route by nipuna
    Route::get('/customerPlan/productQuantity/{id}', [SupplyPlanController::class, 'productQuantity']); //route by nipuna


    Route::get('/customerPlan/settings', [SupplyPlanController::class, 'settings']);
    Route::post('/customerPlan', [SupplyPlanController::class, 'save']);
    Route::get('/customerPlan/allOrderPlan', [SupplyPlanController::class, 'allOrderPlan']);
    Route::delete('/customerPlan/{id}', [SupplyPlanController::class, 'deleteOrder']);
    Route::get('/customerPlan/customerPlan/{id}', [SupplyPlanController::class, 'customerPlan']);
    Route::post('/customerPlan/update', [SupplyPlanController::class, 'updatePlan']);

    //nipuna
    Route::get('/customerPlanData/addOrder/all', [SupplyPlanController::class, 'addorderPurchaceOrder']);

    /**Production Plan (nipuna) */
    Route::get('/Production_Plan/from/{from}/to/{to}', [ProductionPlanController::class, 'getProductionPlanToDate']);

    Route::post('/customerPlanData', [SupplyPlanController::class, 'saveData']);
    Route::delete('/customerPlanData/{id}', [SupplyPlanController::class, 'deleteOrderData']);
    Route::get('/customerPlanData/customerPlanData/{id}', [SupplyPlanController::class, 'customerPlanData']);
    Route::get('/customerPlanData/searchPName', [SupplyPlanController::class, 'searchPName']);
    Route::get('/customerPlanData/getPName/{id}', [SupplyPlanController::class, 'getPName']);
    Route::get('/customerPlanData/allOrderPlanData/{id}', [SupplyPlanController::class, 'allOrderPlanData']);
    Route::post('/customerPlanData/update', [SupplyPlanController::class, 'updatePlanData']);
    Route::delete('/customerPlanData/customerPlanData/{id}', [SupplyPlanController::class, 'disableCustomerPlanData']);
    /** End Customer Plan */

    /**Bill Of Material */
    Route::get('/bomHeader/searchPName', [BillOfMaterialController::class, 'searchPName']);
    Route::get('/bomHeader/getPName/{id}', [BillOfMaterialController::class, 'getPName']);
    Route::post('/bomHeader', [BillOfMaterialController::class, 'save']);
    Route::get('/bomHeader/allbomHeader', [BillOfMaterialController::class, 'allbomHeader']);
    Route::delete('/bomHeader/{id}', [BillOfMaterialController::class, 'deleteBom']);
    Route::get('/bomHeader/bomHeader/{id}', [BillOfMaterialController::class, 'bomHeader']);
    Route::post('/bomHeader/update', [BillOfMaterialController::class, 'updateBomHeader']);
    Route::delete('/bomHeader/bomHeader/{id}', [BillOfMaterialController::class, 'disableBomHeader']);

    Route::get('/bomData/searchPDName', [BillOfMaterialController::class, 'searchPDName']);
    Route::get('/bomData/getPDName/{id}', [BillOfMaterialController::class, 'getPDName']);
    Route::post('/bomData', [BillOfMaterialController::class, 'saveData']);
    Route::get('/bomData/allbomData/{id}', [BillOfMaterialController::class, 'allbomData']);
    Route::delete('/bomData/{id}', [BillOfMaterialController::class, 'deletebomData']);
    Route::get('/bomData/bomData/{id}', [BillOfMaterialController::class, 'bomData']);
    Route::post('/bomData/update', [BillOfMaterialController::class, 'updateBomData']);
    Route::delete('/bomData/bomData/{id}', [BillOfMaterialController::class, 'disableBomData']);
    /** End Bill Of Material*/

    /**Daily Collection Plan */
    Route::get('/DCPlan/searchMaterial', [DailyCollectionPlanController::class, 'searchMaterial']);
    Route::get('/DCPlan/Quantity/Product/{id}/from/{from}/to/{to}', [DailyCollectionPlanController::class, 'Quantity']);
    Route::get('/DCPlan/Plan/{id}/from/{from}/to/{to}', [DailyCollectionPlanController::class, 'PlanRM']);
    Route::get('/DCPlan/RequiredPlan/{id}/from/{from}/to/{to}', [DailyCollectionPlanController::class, 'RequiredPlan']);
    Route::post('/DCPlan/saveTable', [DailyCollectionPlanController::class, 'saveTable']);
    Route::get('/DCPlan/getPName/{id}', [DailyCollectionPlanController::class, 'getPDName']);
    Route::post('/DCPlan/save', [DailyCollectionPlanController::class, 'save']);


    /**Machinary by nipuna */

    Route::get('/machinery/loadSiteId', [PpMachineryController::class, 'loadSiteId']);
    Route::post('/machinery/save', [PpMachineryController::class, 'save']);
    Route::get('/machinery/load', [PpMachineryController::class, 'alldata']);

});
